Chapter 1: Strong Lensing
=========================

In chapter 1, we'll introduce you to strong gravitational lensing and the core PyAutoLens API.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_0_visualization.html>`_
- Setting up visualization.

`Tutorial 1: Grids <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_1_grids.html>`_
- Uniform grids of (y,x) coordinates used for ray-traicng.

`Tutorial 2: Profiles <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_2_profiles.html>`_
- Analytic profiles representing light and mass distributions.

`Tutorial 3: Galaxies <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_3_galaxies.html>`_
- The objects that make up a strong lens.

`Tutorial 4: Planes <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_4 planes.html>`_
- Groups of galaxies at a common redshift.

`Tutorial 5: Ray Tracing <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_5_ray_tracing.html>`_
- Using Grids and Galaxies to perform strong lens ray-tracing!

`Tutorial 6: More Ray Tracing <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_6_more_ray_tracing.html>`_
- Advanced strong lens ray-tracing.

`Tutorial 7: Data <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_7_data.html>`_
- Loading and inspecting telescope imaging ``data`` of a strong lens.

`Tutorial 8: Fitting <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_8_fittingn.html>`_
- Fitting ``data`` with a strong lens model.

`Tutorial 9: Summary <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_1_introduction/tutorial_9_summary.html>`_
- A summary of the chapter.

.. toctree::
   :caption: Tutorials:
   :maxdepth: 1
   :hidden:

   tutorial_0_visualization
   tutorial_1_grids
   tutorial_2_profiles
   tutorial_3_galaxies
   tutorial_4_planes
   tutorial_5_ray_tracing
   tutorial_6_more_ray_tracing
   tutorial_7_data
   tutorial_8_fitting
   tutorial_9_summary
